==> money-to-prisoners-common-9.11.1.tar.gz: money-to-prisoners-common-9.11.1/mtp_common/assets-src/javascripts/modules/analytics.js <==
// Google Analytics Utility module
// This module offers ways to send custom events to Google Analytics:
// - by calling analytics.send. Eg. analytics.send('event', 'tick', 'checkbox')
// - by adding the data-analytics attribute to any element that can be clicked
//   eg <div data-analytics="pageview,/virtual/pageview/,user clicked there"/>
// It needs the google analytics tracking code to be enabled on the page
/* globals ga */
'use strict';

exports.Analytics = {
  attrName: 'analytics',

  init: function () {
    if (this._gaExists()) {
      $('*[data-' + this.attrName + ']').on('click', $.proxy(this._sendFromEvent, this));
    }
  },

  send: function () {
    /*
      Sends to GA passing through all specified arguments.
      It appends an object with page, location and title to the call, if you don't want
      this use rawSend instead.
    */
    if (this._gaExists()) {
      var ga_data = $('span.mtp-ga-data');
      if (ga_data) {
        var ga_override = {
          page: ga_data.data('page'),
          location: ga_data.data('location'),
          title: ga_data.data('title') || document.title,
        };
        [].push.call(arguments, ga_override);
      }
      [].unshift.call(arguments, 'send');
      ga.apply(window, arguments);
    }
  },

  rawSend: function () {
    /*
      Sends to GA passing through all specified arguments.
      Unlike send, it does NOT modify any arguments.
    */
    if (this._gaExists()) {
      [].unshift.call(arguments, 'send');
      ga.apply(window, arguments);
    }
  },

  _sendFromEvent: function (event) {
    var analyticsParams = $(event.currentTarget).data(this.attrName).split(',');
    this.send.apply(this, analyticsParams);
    return true;
  },

  _gaExists: function () {
    return typeof ga === typeof Function;
  }

};

==> money-to-prisoners-common-9.13.0.tar.gz: money-to-prisoners-common-9.13.0/mtp_common/assets-src/javascripts/modules/analytics.js <==
// Google Analytics Utility module
// This module offers ways to send custom events to Google Analytics:
// - by calling analytics.send. Eg. analytics.send('event', 'tick', 'checkbox')
// - by adding the data-analytics attribute to any element that can be clicked
//   eg <div data-analytics="pageview,/virtual/pageview/,user clicked there"/>
// It needs the google analytics tracking code to be enabled on the page
/* globals ga */
'use strict';

exports.Analytics = {
  attrName: 'analytics',

  init: function () {
    if (this._gaExists()) {
      $('*[data-' + this.attrName + ']').on('click', $.proxy(this._sendFromEvent, this));
    }
  },

  send: function () {
    /*
      Sends to GA passing through all specified arguments.
      It appends an object with page, location and title to the call, if you don't want
      this use rawSend instead.
    */
    if (this._gaExists()) {
      var ga_data = $('span.mtp-ga-data');
      if (ga_data) {
        var ga_override = {
          page: ga_data.data('page'),
          location: ga_data.data('location'),
          title: ga_data.data('title') || document.title
        };
        [].push.call(arguments, ga_override);
      }
      [].unshift.call(arguments, 'send');
      ga.apply(window, arguments);
    }
  },

  rawSend: function () {
    /*
      Sends to GA passing through all specified arguments.
      Unlike send, it does NOT modify any arguments.
    */
    if (this._gaExists()) {
      [].unshift.call(arguments, 'send');
      ga.apply(window, arguments);
    }
  },

  _sendFromEvent: function (event) {
    var analyticsParams = $(event.currentTarget).data(this.attrName).split(',');
    this.send.apply(this, analyticsParams);
    return true;
  },

  _gaExists: function () {
    return typeof ga === typeof Function;
  }

};
